[![Documentation Status](https://readthedocs.org/projects/pykafka-tools/badge/?version=latest)](http://pykafka-tools.readthedocs.io/en/latest/?badge=latest)

# pykafka-tools
The pykafka-tools extend the functionalities of python pykafka module.

## Installation
Install this package with
```bash
pip install -e . --process-dependency-links --allow-all-external
```
